@@ -2,14 +2,21 @@ OC.L10N.register(
     "calendar",
     {
     "User-Session unexpectedly expired" : "La sessió ha caducat inesperadament",
-    "Provided email-address is not valid" : "L'adreça de correu no és vàlida",
+    "Provided email-address is not valid" : "L'adreça electrònica proporcionada no és vàlida",
     "%s has published the calendar »%s«" : "%s ha publicat el calendari «%s»",
     "Unexpected error sending email. Please contact your administrator." : "Error inesperat en enviar el correu. Contacteu amb l'administrador.",
+    "Successfully sent email to %1$s" : "Correu enviat correctament a %1$s",
     "Hello," : "Hola,",
     "We wanted to inform you that %s has published the calendar »%s«." : "Us volem informar que %s ha publicat el calendari «%s».",
-    "Open »%s«" : "Obre »%s«",
+    "Open »%s«" : "Obre «%s»",
     "Cheers!" : "A reveure!",
-    "Upcoming events" : "Propers esdeveniments",
+    "Upcoming events" : "Pròxims esdeveniments",
+    "Appointments" : "Cites",
+    "Confirm" : "Confirma",
+    "Appointment:" : "Cita:",
+    "Date:" : "Data:",
+    "Where:" : "Ubicació:",
+    "Description:" : "Descripció:",
     "Calendar" : "Calendari",
     "A Calendar app for Nextcloud" : "Una aplicació de calendari per al Nextcloud",
     "Previous day" : "Dia anterior",
@@ -18,7 +25,6 @@ OC.L10N.register(
     "Next day" : "Dia següent",
     "Next week" : "Setmana següent",
     "Next month" : "Mes següent",
-    "+ New event" : "Esdeveniment nou",
     "Today" : "Avui",
     "Day" : "Dia",
     "Week" : "Setmana",
@@ -26,12 +32,11 @@ OC.L10N.register(
     "List" : "Llista",
     "Delete" : "Suprimeix",
     "Untitled calendar" : "Calendari sense títol",
-    "Edit name" : "Edita nom",
-    "Saving name …" : "S'està desant el nom …",
-    "Edit color" : "Edita color",
-    "Saving color …" : "S'està desant el color …",
+    "Edit name" : "Edita el nom",
+    "Saving name …" : "S'està desant el nom...",
+    "Edit color" : "Edita el color",
+    "Saving color …" : "S'està desant el color...",
     "Copy private link" : "Copia l'enllaç privat",
-    "Download" : "Baixa",
     "Unshare from me" : "Deixa de compartir",
     "An error occurred, unable to change visibility of the calendar." : "S'ha produït un error. No s'ha canviat la visibilitat del calendari.",
     "An error occurred, unable to delete the calendar." : "S'ha produït un error. No s'ha suprimit el calendari.",
@@ -42,18 +47,18 @@ OC.L10N.register(
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Deixant de compartir el calendari en {countdown} segons","S'està deixant de compartir el calendari en {countdown} segons"],
     "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Eliminant el calendari en {countdown} segons","S'està suprimint el calendari en {countdown} segons"],
     "Share link" : "Enllaç de compartició",
-    "Publish calendar" : "Publicar el calendari",
+    "Publish calendar" : "Publica el calendari",
     "Publishing calendar" : "S'està publicant el calendari",
-    "Copy public link" : "Copiar l'enllaç públic",
+    "Copy public link" : "Copia l'enllaç públic",
     "Send link to calendar via email" : "Enviar per correu l'enllaç al calendari",
-    "Enter one address" : "Escriure una adreça",
-    "Sending email …" : "S'està enviant el correu …",
+    "Enter one address" : "Escriviu una adreça",
+    "Sending email …" : "S'està enviant el correu electrònic...",
     "Copy subscription link" : "Copiar l'enllaç de subscripció",
-    "Copying link …" : "S'està copiant l'enllaç …",
-    "Copied link" : "Enllaç copiat",
+    "Copying link …" : "S'està copiant l'enllaç...",
+    "Copied link" : "S'ha copiat l'enllaç",
     "Could not copy link" : "No s'ha pogut copiar l'enllaç",
     "Copy embedding code" : "Copiar el codi per inserir",
-    "Copying code …" : "S'està copiant el codi …",
+    "Copying code …" : "S'està copiant el codi...",
     "Copied code" : "Codi copiat",
     "Could not copy code" : "No s'ha pogut copiar el codi",
     "Delete share link" : "Suprimeix l'enllaç de compartició",
@@ -71,10 +76,10 @@ OC.L10N.register(
     "An error occurred, unable to change the permission of the share." : "Ha succeït un error i no s'ha pogut canviar els permisos de compartició.",
     "+ New calendar" : "+ Calendari nou",
     "New calendar" : "Calendari nou",
-    "Creating calendar …" : "S'està creant el calendari …",
-    "New calendar with task list" : "Nou calendari amb llista de tasques",
+    "Creating calendar …" : "S'està creant el calendari...",
+    "New calendar with task list" : "Calendari nou amb llista de tasques",
     "New subscription from link (read-only)" : "Nova subscripció des d'enllaç (només lectura)",
-    "Creating subscription …" : "S'està creant la subscripció …",
+    "Creating subscription …" : "S'està creant la subscripció...",
     "An error occurred, unable to create the calendar." : "Ha succeït un error i no s'ha pogut crear el calendari.",
     "Please enter a valid link (starting with http://, https://, webcal://, or webcals://)" : "Escriviu un enllaç vàlid (que comenci amb http://, https://, webcal://, o webcals://)",
     "Trash bin" : "Paperera",
@@ -90,7 +95,6 @@ OC.L10N.register(
     "{filename} could not be parsed" : "No s'ha pogut entendre el contingut del fitxer {filename}",
     "No valid files found, aborting import" : "No s'han trobat fitxers que siguin vàlids i s'ha avortat la importació",
     "Import partially failed. Imported {accepted} out of {total}." : "La importació ha fallat parcialment. S'han importat {accepted} d'un total de {total}.",
-    "_Successfully imported %n event_::_Successfully imported %n events._" : ["S'ha importat amb èxit %n event","S'han importat amb èxit %n events."],
     "Automatic" : "Automàtic",
     "Automatic ({detected})" : "Automàtica ({detected})",
     "New setting was not saved successfully." : "No s'ha desat correctament la nova configuració.",
@@ -107,20 +111,35 @@ OC.L10N.register(
     "Create event" : "Crea un esdeveniment",
     "Show shortcuts" : "Mostra les dreceres",
     "Enable birthday calendar" : "Activa el calendari d'aniversaris",
-    "Show tasks in calendar" : "Mostra tasques al calendari",
-    "Enable simplified editor" : "Activa l'editor simplificat",
-    "Limit visible events per view" : "Limita el nombre d'esdeveniments visibles per vista",
+    "Show tasks in calendar" : "Mostra les tasques en el calendari",
+    "Enable simplified editor" : "Habilita l'editor simplificat",
+    "Limit visible events per view" : "Limita el esdeveniments visibles per visualització",
     "Show weekends" : "Mostra els caps de setmana",
     "Show week numbers" : "Mostra el número de la setmana",
     "Copy primary CalDAV address" : "Copia l'adreça CalDEV primària",
     "Copy iOS/macOS CalDAV address" : "Copia l'adreça CalDAV iOS/macOS",
-    "Show keyboard shortcuts" : "Mostra les tecles de drecera",
+    "Show keyboard shortcuts" : "Mostra les dreceres del teclat",
     "Settings & import" : "Paràmetres i importació",
     "CalDAV link copied to clipboard." : "S'ha copiat al porta-retalls l'enllaç CalDAV.",
     "CalDAV link could not be copied to clipboard." : "No s'ha pogut copiar al porta-retalls l'enllaç CalDAV.",
+    "_{duration} minute_::_{duration} minutes_" : ["{duration} minut","{duration} minuts"],
+    "0 minutes" : "0 minuts",
+    "_{duration} hour_::_{duration} hours_" : ["{duration} hora","{duration} hores"],
+    "_{duration} day_::_{duration} days_" : ["{duration} dia","{duration} dies"],
+    "_{duration} week_::_{duration} weeks_" : ["{duration} setmana","{duration} setmanes"],
+    "_{duration} month_::_{duration} months_" : ["{duration} mes","{duration} mesos"],
+    "_{duration} year_::_{duration} years_" : ["{duration} any","{duration} anys"],
     "Location" : "Ubicació",
     "Description" : "Descripció",
+    "Visibility" : "Visibilitat",
+    "Duration" : "Durada",
     "Monday" : "Dilluns",
+    "Tuesday" : "Dimarts",
+    "Wednesday" : "Dimecres",
+    "Thursday" : "Dijous",
+    "Friday" : "Divendres",
+    "Saturday" : "Dissabte",
+    "Sunday" : "Diumenge",
     "Save" : "Desa",
     "Update" : "Actualitza",
     "before at" : "abans a les",
@@ -142,11 +161,13 @@ OC.L10N.register(
     "_day_::_days_" : ["dia","dies"],
     "_week_::_weeks_" : ["setmana","setmanes"],
     "Availability of attendees, resources and rooms" : "Disponibilitat d'assistents, recursos i espais",
-    "Free" : "Lliure",
+    "Free" : "Disponible",
     "Busy (tentative)" : "Ocupat (provisional)",
     "Busy" : "Ocupat",
     "Out of office" : "Fora de l'oficina",
     "Unknown" : "Desconegut",
+    "Accept" : "Accepta",
+    "Decline" : "Rebutja",
     "Tentative" : "Provisional",
     "Create Talk room for this event" : "Crear una sala a Talk per a aquest event",
     "Show busy times" : "Mostra els horaris ocupats",
@@ -164,16 +185,16 @@ OC.L10N.register(
     "Event title" : "Títol de l'esdeveniment",
     "All day" : "Tot el dia",
     "from {startDate}" : "del {startDate}",
-    "from {startDate} at {startTime}" : "de {startDate} a {startTime}",
-    "to {endDate}" : "fins al {endDate}",
-    "to {endDate} at {endTime}" : "fins al {endDate} a les {endTime}",
+    "from {startDate} at {startTime}" : "del {startDate} a les {startTime}",
+    "to {endDate}" : "al {endDate}",
+    "to {endDate} at {endTime}" : "al {endDate} a les {endTime}",
     "Repeat" : "Repeteix",
     "End repeat" : "Finalitza la repetició",
     "Select to end repeat" : "Seleccioneu per finalitzar repetició",
     "never" : "mai",
-    "on date" : "a temps",
+    "on date" : "el dia",
     "after" : "després de",
-    "_time_::_times_" : ["hora","hores"],
+    "_time_::_times_" : ["vegada","vegades"],
     "first" : "primer",
     "third" : "tercer",
     "fourth" : "quart",
@@ -181,7 +202,7 @@ OC.L10N.register(
     "second to last" : "penúltim",
     "last" : "últim",
     "Changes to the recurrence-rule will only apply to this and all future occurrences." : "Els canvis a la regla de recurrència només afectarà en aquesta i futures ocurrències.",
-    "Repeat every" : "Repetir cada",
+    "Repeat every" : "Repeteix cada",
     "By day of the month" : "Per dia del mes",
     "On the" : "Al",
     "_month_::_months_" : ["mes","mesos"],
@@ -189,6 +210,7 @@ OC.L10N.register(
     "weekday" : "dia de la setmana",
     "weekend day" : "dia de cap de setmana",
     "The recurrence definition of this event is not fully supported by Nextcloud. If you edit the recurrence-options, certain recurrences may be lost." : "La definició de recurrència d'aquest event no es del tot compatible amb Nextcloud. Si canvieu les opcions de recurrència, es poden perdre certes recurrències.",
+    "Suggestions" : "Suggeriments",
     "More" : "Més",
     "Update this occurrence" : "Actualitza aquesta ocurrència",
     "Update this and all future" : "Actualitza aquesta i les futures",
@@ -203,8 +225,8 @@ OC.L10N.register(
     "to {formattedDate} at {formattedTime}" : "al {formattedDate} a les {formattedTime}",
     "on {formattedDate} at {formattedTime}" : "el {formattedDate} a les {formattedTime}",
     "{formattedDate} at {formattedTime}" : "{formattedDate} a les {formattedTime}",
-    "Please enter a valid date" : "Si us plau, escriu una data vàlida",
-    "Please enter a valid date and time" : "Si us plau, escriu una data i hora vàlides",
+    "Please enter a valid date" : "Indiqueu una data vàlida",
+    "Please enter a valid date and time" : "Indiqueu una data i hora vàlides",
     "Global" : "Global",
     "Personal" : "Personal",
     "No more events today" : "Avui no hi ha més esdeveniments",
@@ -219,8 +241,9 @@ OC.L10N.register(
     "Delete this and all future" : "Suprimeix aquesta i les ocurrències futures",
     "Details" : "Detalls",
     "Attendees" : "Assistents",
+    "Resources" : "Recursos",
     "Close" : "Tanca",
-    "Show more details" : "Mostra'n més detalls",
+    "Show more details" : "Mostra més detalls",
     "Subscribe to {name}" : "Subscriure a {name}",
     "Download {name}" : "Baixa {name}",
     "Anniversary" : "Commemoració",
@@ -231,13 +254,13 @@ OC.L10N.register(
     "Meeting" : "Reunió",
     "Miscellaneous" : "Miscel·lània",
     "Non-working hours" : "Hores fora de la feina",
-    "Not in office" : "Fora de la oficina",
+    "Not in office" : "Fora de l'oficina",
     "Phone call" : "Trucada telefònica",
     "Sick day" : "Malaltia",
     "Special occasion" : "Ocasió especial",
     "Travel" : "Viatge",
     "Vacation" : "Vacances",
-    "Midnight on the day the event starts" : "Mitjanit del dia que comença l'event",
+    "Midnight on the day the event starts" : "Mitjanit del dia que comença l'esdeveniment",
     "_%n day before the event at {formattedHourMinute}_::_%n days before the event at {formattedHourMinute}_" : ["%n dia abans de l'event a les {formattedHourMinute}","%n dies abans de l'event a les {formattedHourMinute}"],
     "_%n week before the event at {formattedHourMinute}_::_%n weeks before the event at {formattedHourMinute}_" : ["%n setmana abans de l'event a les  {formattedHourMinute}","%n setmanes abans de l'event a les {formattedHourMinute}"],
     "on the day of the event at {formattedHourMinute}" : "el dia de l'event a les {formattedHourMinute}",
@@ -273,11 +296,12 @@ OC.L10N.register(
     "W" : "S",
     "%n more" : "%n més",
     "No events to display" : "No hi ha esdeveniments per visualitzar",
-    "_+%n more_::_+%n more_" : ["+%n més","+%n més"],
+    "_+%n more_::_+%n more_" : ["i %n més","i %n més"],
     "No events" : "Cap esdeveniment",
     "Create a new event or change the visible time-range" : "Crea un esdeveniment nou o canvia l'interval de temps visible",
     "It might have been deleted, or there was a typo in a link" : "Pot ser que s'hagi suprimit o que hi hagi un error tipogràfic en un enllaç",
     "It might have been deleted, or there was a typo in the link" : "Pot ser que s'hagi suprimit o que hi hagi un error tipogràfic a l'enllaç",
+    "Meeting room" : "Sala de reunions",
     "When shared show" : "Mostrar a compartits",
     "When shared show full event" : "Quan es comparteix, mostra l'esdeveniment complet",
     "When shared show only busy" : "Quan es comparteix, mostra només si està ocupat",
@@ -289,15 +313,15 @@ OC.L10N.register(
     "Confirmed" : "Confirmat",
     "Canceled" : "Cancel·lat",
     "Confirmation about the overall status of the event." : "Confirmació sobre l'estat general de l'event.",
-    "Show as" : "Mostra com",
+    "Show as" : "Mostra'm com a",
     "Take this event into account when calculating free-busy information." : "Tenir en compte aquest event quan es calculi informació sobre disponibilitat-ocupació.",
     "Categories" : "Categories",
     "Categories help you to structure and organize your events." : "Les categories us ajuden a estructurar i organitzar els vostres events.",
     "Search or add categories" : "Cercar o afegir categories",
     "Add this as a new category" : "Afegeix-ho com una nova categoria",
-    "Custom color" : "Color a mida",
+    "Custom color" : "Color personalitzat",
     "Special color of this event. Overrides the calendar-color." : "Color especial per a aquest event. Sobreescriu el color del calendari.",
-    "Chat room for event" : "Sala de xat per l'event",
+    "Chat room for event" : "Sala de xat per a l'esdeveniment",
     "Imported {filename}" : "{filename} importat",
     "Meditation" : "Meditació",
     "Relaxing" : "Relax",
@@ -305,11 +329,15 @@ OC.L10N.register(
     "Presentation" : "Presentació",
     "Camping" : "Acampada",
     "Camp" : "Campament",
+    "Garden" : "Jardí",
+    "Farm" : "Granja",
     "Movie" : "Pel·lícula",
-    "Cinema" : "Sala de cinema",
+    "Cinema" : "Cinema",
     "Graduation" : "Graduació",
     "Brainstorm" : "Pluja d'idees",
-    "Review" : "Revisa",
+    "Review" : "Revisió",
+    "Audit" : "Auditoria",
+    "Inspection" : "Inspecció",
     "Baseball" : "Beisbol",
     "Meet" : "Reunió",
     "Planning" : "Planificació",
@@ -317,7 +345,7 @@ OC.L10N.register(
     "Retrospective" : "Retrospectiva",
     "Office" : "Oficina",
     "Contributor week" : "Setmana del contribuïdor",
-    "Mail" : "Correu electrònic",
+    "Mail" : "Correu",
     "Soccer" : "Futbol",
     "Football" : "Futbol americà",
     "Gaming" : "Jugar",
@@ -349,17 +377,20 @@ OC.L10N.register(
     "Gym" : "Gimnàs",
     "Barber" : "Barber",
     "Haircut" : "Perruqueria",
+    "Hairdresser" : "Perruquer",
     "Exam" : "Examen",
+    "Written test" : "Prova escrita",
+    "Oral test" : "Prova oral",
     "Working" : "Feina",
     "New Years Eve" : "Cap d'any",
     "NYE" : "Cap d'any",
     "Fireworks" : "Focs artificials",
-    "Running" : "Còrrer",
-    "Go for a run" : "Sortir a còrrer",
+    "Running" : "Córrer",
+    "Go for a run" : "Sortir a córrer",
     "Marathon" : "Marató",
-    "Video-conference" : "Vídeo-conferència",
+    "Video-conference" : "Videoconferència",
     "Conference-call" : "Trucada de conferència",
-    "Video-call" : "Vídeo-trucada",
+    "Video-call" : "Videotrucada",
     "Video-chat" : "Vídeo-xat",
     "Video-meeting" : "Vídeo-reunió",
     "Call" : "Trucada",
@@ -373,6 +404,7 @@ OC.L10N.register(
     "Pair" : "Parella",
     "Lecture" : "Lectura",
     "Seminar" : "Seminari",
+    "Teaching" : "Docència",
     "Photograph" : "Fotografia",
     "Party" : "Festa",
     "Celebration" : "Celebració",
@@ -383,6 +415,8 @@ OC.L10N.register(
     "Wine tasting" : "Tasta de vins",
     "Golf" : "Golf",
     "Dinner" : "Sopar",
-    "Lunch" : "Dinar"
+    "Lunch" : "Dinar",
+    "Appointment not found" : "No s'ha trobat la cita",
+    "User not found" : "No s'ha trobat l'usuari"
 },
 "nplurals=2; plural=(n != 1);");
