@@ -17,7 +17,6 @@ OC.L10N.register(
     "Next day" : "Næste dag",
     "Next week" : "Næste uge",
     "Next month" : "Næste måned",
-    "+ New event" : "+ Ny begivenhed",
     "Today" : "I dag",
     "Day" : "Dag",
     "Week" : "Uge",
@@ -29,7 +28,6 @@ OC.L10N.register(
     "Edit color" : "Rediger farve",
     "Saving color …" : "Gemmer farve…",
     "Copy private link" : "Kopier privat link",
-    "Download" : "Hent",
     "Unshare from me" : "Fjern deling fra mig",
     "An error occurred, unable to change visibility of the calendar." : "Kalenderens synlighed kunne ikke ændres.",
     "An error occurred, unable to delete the calendar." : "Kalenderen kunne ikke slettes.",
