@@ -14,7 +14,6 @@ OC.L10N.register(
     "Next day" : "Proximo día",
     "Next week" : "Proxima semana",
     "Next month" : "Proximo mes",
-    "+ New event" : "+ Nuevo evento",
     "Today" : "Hoy",
     "Day" : "Día",
     "Week" : "Semana",
@@ -23,7 +22,6 @@ OC.L10N.register(
     "Delete" : "Borrar",
     "Edit name" : "Editar nombre",
     "Edit color" : "Editar color",
-    "Download" : "Descargar",
     "Share link" : "Compartir link",
     "Copy public link" : "Copiar link publico",
     "Copied link" : "Link copiado",
