@@ -21,7 +21,6 @@ OC.L10N.register(
     "Next day" : "روز بعد",
     "Next week" : "هفته بعد",
     "Next month" : "ماه بعد",
-    "+ New event" : "+ رویداد جدید",
     "Today" : "امروز",
     "Day" : "روز",
     "Week" : "هفته",
@@ -34,7 +33,6 @@ OC.L10N.register(
     "Edit color" : "ویرایش رنگ",
     "Saving color …" : "ذخیره رنگ",
     "Copy private link" : "کپی کردن پیوند خصوصی",
-    "Download" : "دانلود",
     "Unshare from me" : "بی خبر از من",
     "An error occurred, unable to change visibility of the calendar." : "خطایی روی داد ، قادر به تغییر دیدگاه تقویم نیست.",
     "An error occurred, unable to delete the calendar." : "خطایی روی داد ، قادر به حذف تقویم نیست.",
@@ -89,7 +87,6 @@ OC.L10N.register(
     "Cancel" : "منصرف شدن",
     "_Import calendar_::_Import calendars_" : ["وارد کردن تقویم","وارد کردن تقویم ها"],
     "Import partially failed. Imported {accepted} out of {total}." : "وارد کردن تا حدودی انجام نشد. وارد شده {accepted} بیرون از {total}.",
-    "_Successfully imported %n event_::_Successfully imported %n events._" : ["رویداد %n با موفقیت وارد شده","رویداد ها  %n با موفقیت وارد شده."],
     "Automatic" : "خودکار",
     "Automatic ({detected})" : "خودکار ({شناسایی})",
     "New setting was not saved successfully." : "تنظیم جدید با موفقیت ذخیره نشد.",
