@@ -16,7 +16,6 @@ OC.L10N.register(
     "Next day" : "Hari setelah",
     "Next week" : "Minggu setelah",
     "Next month" : "Bulan setelah",
-    "+ New event" : "+ Acara baru",
     "Today" : "Hari Ini",
     "Day" : "Hari",
     "Week" : "Minggu",
@@ -28,7 +27,6 @@ OC.L10N.register(
     "Edit color" : "Edit warna",
     "Saving color …" : "Menyimpan warna …",
     "Copy private link" : "Salin tautan privat",
-    "Download" : "Unduh",
     "An error occurred, unable to change visibility of the calendar." : "Terjadi galat, tidak dapat mengubah visibilitas kalender.",
     "An error occurred, unable to delete the calendar." : "Terjadi galat, tidak dapat menghapus kalender.",
     "Calendar link copied to clipboard." : "Tautan kalender disalin ke papan klip.",
@@ -78,7 +76,6 @@ OC.L10N.register(
     "_Import calendar_::_Import calendars_" : ["Impor kalender"],
     "No valid files found, aborting import" : "Berkas valid tidak ditemukan, impor dibatalkan",
     "Import partially failed. Imported {accepted} out of {total}." : "Sebagian impor gagal. Dari {total} hanya {accepted} berhasil impor.",
-    "_Successfully imported %n event_::_Successfully imported %n events._" : ["Berhasil impor %n acara."],
     "Automatic" : "Otomatis",
     "Automatic ({detected})" : "Otomatis ({detected})",
     "New setting was not saved successfully." : "Setelan baru tidak berhasil tersimpan.",
