@@ -17,7 +17,6 @@ OC.L10N.register(
     "Next day" : "Næsta dag",
     "Next week" : "Næsta viku",
     "Next month" : "Næsti mánuður",
-    "+ New event" : "+ Nýr atburður",
     "Today" : "Í dag",
     "Day" : "Dagur",
     "Week" : "Vika",
@@ -30,7 +29,6 @@ OC.L10N.register(
     "Edit color" : "Breyta lit",
     "Saving color …" : "Vista lit …",
     "Copy private link" : "Afrita einkatengil",
-    "Download" : "Sækja",
     "Unshare from me" : "Hætta deilingu frá mér",
     "An error occurred, unable to change visibility of the calendar." : "Villa kom upp, gat ekki breytt sýnileika dagatalsins.",
     "An error occurred, unable to delete the calendar." : "Villa kom upp, gat ekki eytt dagatalinu.",
@@ -85,7 +83,6 @@ OC.L10N.register(
     "{filename} is an unsupported file-type" : "{filename} er óstudd skráartegund",
     "{filename} could not be parsed" : "Ekki var hægt að þátta {filename}",
     "No valid files found, aborting import" : "Engar gildar skrár fundust, hætti innflutningi",
-    "_Successfully imported %n event_::_Successfully imported %n events._" : ["Innflutningur tókst á %n atburði","Innflutningur tókst á %n atburðum"],
     "Automatic" : "Sjálfvirkt",
     "Automatic ({detected})" : "Sjálfvirkt ({detected})",
     "New setting was not saved successfully." : "Ekki tókst að vista nýju stillinguna.",
