@@ -24,7 +24,6 @@ OC.L10N.register(
     "Next day" : "翌日",
     "Next week" : "翌週",
     "Next month" : "翌月",
-    "+ New event" : "+ 新しいイベント",
     "Today" : "今日",
     "Day" : "日",
     "Week" : "週",
@@ -41,7 +40,6 @@ OC.L10N.register(
     "Edit color" : "色を編集",
     "Saving color …" : "色を保存しています …",
     "Copy private link" : "プライベートリンクをコピー",
-    "Download" : "ダウンロード",
     "Unshare from me" : "共有を自分から解除",
     "An error occurred, unable to change visibility of the calendar." : "エラーが発生したため、カレンダーの表示状態を変更できません。",
     "An error occurred, unable to delete the calendar." : "エラーが発生したため、カレンダーを削除できません。",
@@ -107,7 +105,6 @@ OC.L10N.register(
     "{filename} could not be parsed" : "{filename} が解析できませんでした",
     "No valid files found, aborting import" : "有効なファイルが見つかりませんでした。インポートを中止します。",
     "Import partially failed. Imported {accepted} out of {total}." : "インポートが部分的に失敗しました。 {total}のうち{accepted}をインポートしました。",
-    "_Successfully imported %n event_::_Successfully imported %n events._" : ["%nイベントを正常にインポートしました"],
     "Automatic" : "自動",
     "Automatic ({detected})" : "自動 ({detected})",
     "New setting was not saved successfully." : "新しい設定は正常に保存されませんでした。",
