@@ -8,14 +8,12 @@ OC.L10N.register(
     "Cheers!" : "Priekā!",
     "Calendar" : "Kalendārs",
     "A Calendar app for Nextcloud" : "Kalendāra lietotne priekš Nextcloud",
-    "+ New event" : "+ Jauns notikums",
     "Today" : "Šodien",
     "Day" : "Diena",
     "Week" : "Nedēļa",
     "Month" : "Mēnesis",
     "List" : "Saraksts",
     "Delete" : "Dzēst",
-    "Download" : "Lejupielādēt",
     "Share link" : "Koplietot saiti",
     "Share with users or groups" : "Koplietot ar lietotājiem vai grupām",
     "No users or groups" : "Nav lietotāji vai grupas",
