@@ -19,7 +19,6 @@ OC.L10N.register(
     "Next day" : "Следен ден",
     "Next week" : "Следна недела",
     "Next month" : "Следен месец",
-    "+ New event" : "+ Нов настан",
     "Today" : "Денес",
     "Day" : "Ден",
     "Week" : "Недела",
@@ -32,7 +31,6 @@ OC.L10N.register(
     "Edit color" : "Уреди бои",
     "Saving color …" : "Зачувување боја …",
     "Copy private link" : "Копирај приватен линк",
-    "Download" : "Преземи",
     "Unshare from me" : "Не споделувај со мене",
     "An error occurred, unable to change visibility of the calendar." : "Настана грешка, неможе да се промени видливоста на календарот.",
     "An error occurred, unable to delete the calendar." : "Настана грешка, неможе да се избрише календарот.",
@@ -93,7 +91,6 @@ OC.L10N.register(
     "{filename} could not be parsed" : "Датотеката {filename} не може да се анализира",
     "No valid files found, aborting import" : "Не е пронајдена валидна датотека, увозот е откажан",
     "Import partially failed. Imported {accepted} out of {total}." : "Увозот е делумно неуспешен. Увезени {accepted} од вкупно {total}.",
-    "_Successfully imported %n event_::_Successfully imported %n events._" : ["Успешно увезен %n настан","Успешно увезени %n настани."],
     "Automatic" : "Автоматски",
     "Automatic ({detected})" : "Автоматски ({detected})",
     "New setting was not saved successfully." : "Неуспешно зачувување на промените.",
