@@ -16,7 +16,6 @@ OC.L10N.register(
     "Next day" : "Neste dag",
     "Next week" : "Neste uke",
     "Next month" : "Neste måned",
-    "+ New event" : "+ Ny hendelse",
     "Today" : "I dag",
     "Day" : "Dag",
     "Week" : "Uke",
@@ -29,7 +28,6 @@ OC.L10N.register(
     "Edit color" : "Rediger farge",
     "Saving color …" : "Lagrer farge  ...",
     "Copy private link" : "Kopier privat lenke",
-    "Download" : "Last ned",
     "Unshare from me" : "Fjern deling fra meg",
     "An error occurred, unable to change visibility of the calendar." : "En feil oppstod, kan ikke endre synlighet til kalenderen.",
     "An error occurred, unable to delete the calendar." : "En feil oppstod, kan ikke slette kalenderen. ",
@@ -86,7 +84,6 @@ OC.L10N.register(
     "{filename} could not be parsed" : "{filename} kunne ikke leses",
     "No valid files found, aborting import" : "Ingen gyldig filer funnet, avbryter importering",
     "Import partially failed. Imported {accepted} out of {total}." : "Importering mislykkes delvis. Importerte {accepted} av {total}. ",
-    "_Successfully imported %n event_::_Successfully imported %n events._" : ["Importerte %navtale","Importerte %n hendelser."],
     "Automatic" : "Automatisk",
     "Automatic ({detected})" : "Automatisk ({detected})",
     "New setting was not saved successfully." : "Ny innstilling ble ikke lagret.",
