@@ -14,7 +14,6 @@ OC.L10N.register(
     "Next day" : "Jorn seguent",
     "Next week" : "Setmana seguenta",
     "Next month" : "Mes seguent",
-    "+ New event" : "+ eveniment novèl",
     "Today" : "Uèi",
     "Day" : "Jorn",
     "Week" : "Aquesta setmana",
@@ -29,7 +28,6 @@ OC.L10N.register(
     "Edit color" : "Modificar la color",
     "Saving color …" : "Enregistrament de la color …",
     "Copy private link" : "Copiar lo ligam privat",
-    "Download" : "Telecargar",
     "Share link" : "Partejar lo ligam",
     "Publish calendar" : "Publicar lo calendièr",
     "Copy public link" : "Copiar lo ligam public",
